@@ -1,3 +1,4 @@
+import gc
 from time import time
 
 from nozdormu.util import format_time
@@ -19,13 +20,23 @@ class BenchBatch:
 
     def run(self):
         """Peform setup/run method/teardown and time it"""
-        self.count += 1
+        # Manual GC
+        gc.collect()
+
+        # Warm up
+        self.setUp()
+        self.method()
+        self.tearDown()
+
+        # Timed run
         self.setUp()
         start = time()
         self.method()
         self.totalTime += time() - start
         self.tearDown()
 
+        self.count += 1
+
     def setUp(self):
         pass
 
